/// <reference types="node" />
import 'deps-check';
import Express from 'express';
import { SessionOptions } from 'express-session';
import { DBOptions } from './dbInit';
import { BaseDB, SchemaConstraint } from './Orm/PostgresqlDriver';
import * as bodyparser from 'body-parser';
import serveStatic from 'serve-static';
import https from 'https';
import http from 'http';
import { Pool } from 'pg';
export * from './di';
export * from './graphQLUtils';
export * from './Orm/PostgresqlDriver';
export * from './request';
export * from './testUtils';
export * from './utils';
export * from './dateUtils';
export * from './assert';
export * from './logger';
export declare const bodyParser: typeof bodyparser;
export declare const ENV: string;
export declare const PRODUCTION: boolean;
interface Options {
    https?: {
        privateKeyFile: string;
        certificateFile: string;
        port?: number;
    };
    session?: SessionOptions;
    db?: DBOptions;
    graphql: {
        url: string;
        schema: string;
        resolver: object;
    };
    static?: {
        rootDir: string;
        options?: serveStatic.ServeStaticOptions;
    };
    parcel?: {
        indexFilename: string;
    };
    errors: {
        unknown: unknown;
    };
    port: number;
}
interface Result<DBSchema extends SchemaConstraint> {
    server: https.Server | http.Server;
    express: Express.Express;
    projectDir: string;
    db: BaseDB<DBSchema>;
    dbPool: Pool;
}
export declare function createGraphqApp<DBSchema extends SchemaConstraint>(options: Options, runMiddlewares?: (app: Result<DBSchema>) => Promise<void>): Promise<Result<DBSchema>>;
export declare function asyncThread(fn: (req: Express.Request, res: Express.Response) => Promise<unknown>): Express.Handler;
//# sourceMappingURL=index.d.ts.map