import SMTPTransport from 'nodemailer/lib/smtp-transport';
import { LoggingOptions as GoogleStackDriverOptions } from '@google-cloud/logging';
export declare class BaseException<T> extends Error {
    name: string;
    json: T;
    kind: string;
    constructor(name: string, json?: T);
}
export declare class ClientException<T = object> extends BaseException<T> {
}
export declare class ExternalException<T = object> extends BaseException<T> {
}
export declare class Exception<T = object> extends BaseException<T> {
}
declare type Levels = keyof typeof levels;
declare type LoggerStreamConfig = {
    level: Levels;
    type: 'file';
    file: string;
    rotate?: 'daily';
} | {
    level: Levels;
    type: 'stdout';
} | {
    level: Levels;
    type: 'stackdriver';
    options: GoogleStackDriverOptions;
    logName: string;
} | {
    level: Levels;
    type: 'email';
    options: SMTPTransport.Options;
    from: string;
    to: string;
    subject: {
        start: string;
        error: string;
    };
};
export interface LoggerSettings {
    streams: LoggerStreamConfig[];
}
export declare class Logger {
    protected streams: LoggerStream[];
    constructor(settings: LoggerSettings);
    protected setSettings(settings: LoggerSettings): void;
    protected log(type: Levels, name: string, json?: object): void;
    info(name: string, json?: object): void;
    clientError(name: string, json?: object): void;
    warn(name: string, json?: object): void;
    trace(name: string, json?: object): void;
    error(name: string | Error, json?: object): void;
    external(name: string, json?: object): void;
}
declare abstract class LoggerStream {
    level: number;
    constructor(level: number);
    abstract write(id: string, parentId: string, date: Date, type: Levels, name: string, json: object): void;
}
declare const levels: {
    error: number;
    warn: number;
    external: number;
    info: number;
    clientError: number;
    trace: number;
};
export declare const logger: Logger;
export declare function setLoggerSettings(settings: LoggerSettings): void;
export {};
//# sourceMappingURL=logger.d.ts.map